@@ -76,6 +76,7 @@ def hyperpredictions(maadstoken,pkey,theinputdata,host,port,usereverseproxy=0,mi
 
 def returndata(buffer,label):
       #print("LABEL: %s" % (label))
+    try:
       if label=='PKEY:':
          val=""
          pattern = re.compile('\s*[,\n]\s*')
@@ -190,8 +191,9 @@ def returndata(buffer,label):
          rval=[fdate,inp,pred,acc]
       else:
          return "%s not found" % (label)
-          
-      return rval
+    except Exception as e:
+        return "ERROR retrieving label data: %s" % e
+    return rval
 
 def retraining(maadstoken,pkey,thefile,autofeature,removeoutliers,hasseasonality,dependentvariable,url,summer,winter,shoulder,trainingpercentage,retrainingdays,retraindeploy,username='',passw='',company='',email=''):
 
